cosmpy.protos.cosmos.bank.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.bank.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.bank.v1beta1.bank_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.bank.v1beta1.bank_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.bank.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.bank.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.bank.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.bank.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.bank.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service.

  static AllBalances(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Balance(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DenomMetadata(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DenomsMetadata(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SupplyOf(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static TotalSupply(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.bank.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service.

  AllBalances(request, context)

    AllBalances queries the balance of all coins for a single account.

  Balance(request, context)

    Balance queries the balance of a single coin for a single account.

  DenomMetadata(request, context)

    DenomsMetadata queries the client metadata of a given coin denomination.

  DenomsMetadata(request, context)

    DenomsMetadata queries the client metadata for all registered coin denominations.

  Params(request, context)

    Params queries the parameters of x/bank module.

  SupplyOf(request, context)

    SupplyOf queries the supply of a single coin.

  TotalSupply(request, context)

    TotalSupply queries the total supply of all coins.

class cosmpy.protos.cosmos.bank.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service.

cosmpy.protos.cosmos.bank.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.bank.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.bank.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.bank.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the bank Msg service.

  static MultiSend(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Send(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.bank.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the bank Msg service.

  MultiSend(request, context)

    MultiSend defines a method for sending coins from some accounts to other accounts.

  Send(request, context)

    Send defines a method for sending coins from one account to another account.

class cosmpy.protos.cosmos.bank.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the bank Msg service.

cosmpy.protos.cosmos.bank.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents